"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class WorkflowsModelTypedDict(TypedDict):
    r"""All translations for given locale organized by workflow identifier"""


class WorkflowsModel(BaseModel):
    r"""All translations for given locale organized by workflow identifier"""


class LayoutsModelTypedDict(TypedDict):
    r"""All translations for given locale organized by layout identifier"""


class LayoutsModel(BaseModel):
    r"""All translations for given locale organized by layout identifier"""


class GetMasterJSONResponseDtoTypedDict(TypedDict):
    workflows: WorkflowsModelTypedDict
    r"""All translations for given locale organized by workflow identifier"""
    layouts: LayoutsModelTypedDict
    r"""All translations for given locale organized by layout identifier"""


class GetMasterJSONResponseDto(BaseModel):
    workflows: WorkflowsModel
    r"""All translations for given locale organized by workflow identifier"""

    layouts: LayoutsModel
    r"""All translations for given locale organized by layout identifier"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .uploadtranslationsrequestdto import (
    UploadTranslationsRequestDto,
    UploadTranslationsRequestDtoTypedDict,
)
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, RequestMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TranslationControllerUploadTranslationFilesRequestTypedDict(TypedDict):
    upload_translations_request_dto: UploadTranslationsRequestDtoTypedDict
    r"""Translation files upload body details"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class TranslationControllerUploadTranslationFilesRequest(BaseModel):
    upload_translations_request_dto: Annotated[
        UploadTranslationsRequestDto,
        FieldMetadata(request=RequestMetadata(media_type="multipart/form-data")),
    ]
    r"""Translation files upload body details"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updateworkflowdto import UpdateWorkflowDto, UpdateWorkflowDtoTypedDict
from .workflowresponsedto import WorkflowResponseDto, WorkflowResponseDtoTypedDict
from novu_py.types import BaseModel
from novu_py.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class WorkflowControllerUpdateRequestTypedDict(TypedDict):
    workflow_id: str
    update_workflow_dto: UpdateWorkflowDtoTypedDict
    r"""Workflow update details"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class WorkflowControllerUpdateRequest(BaseModel):
    workflow_id: Annotated[
        str,
        pydantic.Field(alias="workflowId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    update_workflow_dto: Annotated[
        UpdateWorkflowDto,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Workflow update details"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class WorkflowControllerUpdateResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: WorkflowResponseDtoTypedDict


class WorkflowControllerUpdateResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: WorkflowResponseDto



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class GetContextResponseDtoDataTypedDict(TypedDict):
    pass


class GetContextResponseDtoData(BaseModel):
    pass


class GetContextResponseDtoTypedDict(TypedDict):
    type: str
    id: str
    data: GetContextResponseDtoDataTypedDict
    created_at: str
    updated_at: str


class GetContextResponseDto(BaseModel):
    type: str

    id: str

    data: GetContextResponseDtoData

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getenvironmenttagsdto import GetEnvironmentTagsDto, GetEnvironmentTagsDtoTypedDict
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, PathParamMetadata
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EnvironmentsControllerGetEnvironmentTagsRequestTypedDict(TypedDict):
    environment_id: str
    r"""Environment internal ID (MongoDB ObjectId) or identifier"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class EnvironmentsControllerGetEnvironmentTagsRequest(BaseModel):
    environment_id: Annotated[
        str,
        pydantic.Field(alias="environmentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Environment internal ID (MongoDB ObjectId) or identifier"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class EnvironmentsControllerGetEnvironmentTagsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[GetEnvironmentTagsDtoTypedDict]


class EnvironmentsControllerGetEnvironmentTagsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[GetEnvironmentTagsDto]
